Clojure only.

blanket.core


coverclj

(cover x
       &
       {:keys [print-method ns]
        :or {print-method default-print-method ns *ns*}})

Hides data structure internals from printing in other namespaces

Hides data structure internals from printing in other namespaces
raw docstring

(print-as x)

revealclj

(reveal x)

Reveals previously hidden data structure internals

Reveals previously hidden data structure internals
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries