(cover x
&
{:keys [print-method ns]
:or {print-method default-print-method ns *ns*}})Hides data structure internals from printing in other namespaces
Hides data structure internals from printing in other namespaces
(print-as x)(reveal x)Reveals previously hidden data structure internals
Reveals previously hidden data structure internals
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |